require 'gem2deb/rake/spectask'

Gem2Deb::Rake::RSpecTask.new do |spec|
  spec.pattern = './spec/**/*_spec.rb'
  spec.exclude_pattern = [
    './spec/gemspec_spec.rb',           # assumes bundler is loaded
    './spec/assets_spec.rb',            # loads Rakefile, which requires bundler/setup
    './spec/sandbox/**/*_spec.rb',      # needs bundle install of unpackaged gems
  ].join(",")
end
